@@ -3,7 +3,6 @@ import re
 import time
 from PIL import Image
 import xml.etree.ElementTree as ET
-import xvfbwrapper
 from selenium import webdriver
 from gmapsbounds import constants
 
@@ -119,3 +118,41 @@ def get_menu_borders(rgb_image):
             return constants.MENU_BORDERS
     return constants.MENU_BORDERS_WITH_ADS
 
+def add_coordinates_to_boundary(boundary, nodes):
+    linear_ring = ET.SubElement(boundary, 'LinearRing')
+    coordinates = ET.SubElement(linear_ring, 'coordinates')
+    text_list = []
+    for node in nodes:
+        coords_as_strings = [str(coord) for coord in node.get_lat_lng()]
+        text_list.append(','.join(reversed(coords_as_strings)))
+    coordinates.text = '\n'.join(text_list)
+
+def add_polygons_to_placemark(placemark, polygons):
+     for poly in polygons:
+        polygon = ET.SubElement(placemark, 'Polygon')
+        polygon.append(makeelement('extrude', '1'))
+        polygon.append(makeelement('altitudeMode', 'relativeToGround'))
+        boundary = ET.SubElement(polygon, 'outerBoundaryIs')
+        add_coordinates_to_boundary(boundary, poly.nodes)
+        if poly.inner is not None:
+            boundary = ET.SubElement(polygon, 'innerBoundaryIs')
+            add_coordinates_to_boundary(boundary, poly.nodes)
+
+def add_placemark(root, location):
+    placemark = ET.SubElement(root, 'Placemark')
+    placemark.append(makeelement('name', location.name))
+    add_polygons_to_placemark(placemark, location.polygons)
+
+def write_to_kml(location_list, filename):
+    if filename.endswith('.kml'):
+        root = makeelement('kml', attributes={'xmlns': 'http://www.opengis.net/kml/2.2'})
+        for location in location_list:
+            add_placemark(root, location)
+        with open(filename, 'w') as f:
+            f.write(ET.tostring(root).decode('utf8'))
+    else:
+        for location in location_list:
+            root = makeelement('kml', attributes={'xmlns': 'http://www.opengis.net/kml/2.2'})
+            add_placemark(root, location)
+            with open('{}.kml'.format(os.path.join(filename, location.name)), 'w') as f:
+                f.write(ET.tostring(root).decode('utf8'))
